import glob
import importlib
import os
import sys

import onnx
import numpy

from onnx_model_maker import mod_name
from onnx_model_maker import omm
from onnx_model_maker import OPSET_VER


modules = glob.glob(os.path.join(os.path.dirname(__file__), "op_ver_*.py"))
for m in modules:
  spec = importlib.util.spec_from_file_location(os.path.basename(m)[:-3], m)
  spec.loader.exec_module(importlib.util.module_from_spec(spec))


def Input(*args):
  inputs = []
  for i, a in enumerate(args):
    t = onnx.numpy_helper.from_array(a)
    vi = onnx.helper.make_tensor_value_info(f"_t_Input_{i}",
                                            t.data_type, t.dims)
    omm.model.graph.input.append(vi)
    inputs.append(vi.name)
  return inputs


def Output(*args):
  for i, a in enumerate(args):
    if type(a) == numpy.ndarray:
      t = onnx.numpy_helper.from_array(a)
      vi = onnx.helper.make_tensor_value_info(f"_t_Output_{i}", t.data_type,
                                              t.dims)
      omm.model.graph.output.append(vi)
    elif type(a) == str:
      vi = onnx.helper.make_empty_tensor_value_info(a)
      omm.model.graph.output.append(vi)
    elif type(a) == onnx.NodeProto:
      for o in a.output:
        vi = onnx.helper.make_empty_tensor_value_info(o)
        omm.model.graph.output.append(vi)
    else:
      raise Exception


def Abs(*args, **kwargs):
  schema = onnx.defs.get_schema("Abs",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Abs")(*args, **kwargs)


def Acos(*args, **kwargs):
  schema = onnx.defs.get_schema("Acos",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Acos")(*args, **kwargs)


def Acosh(*args, **kwargs):
  schema = onnx.defs.get_schema("Acosh",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Acosh")(*args, **kwargs)


def Adagrad(*args, **kwargs):
  schema = onnx.defs.get_schema("Adagrad",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Adagrad")(*args, **kwargs)


def Adam(*args, **kwargs):
  schema = onnx.defs.get_schema("Adam",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Adam")(*args, **kwargs)


def Add(*args, **kwargs):
  schema = onnx.defs.get_schema("Add",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Add")(*args, **kwargs)


def And(*args, **kwargs):
  schema = onnx.defs.get_schema("And",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.And")(*args, **kwargs)


def ArgMax(*args, **kwargs):
  schema = onnx.defs.get_schema("ArgMax",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ArgMax")(*args, **kwargs)


def ArgMin(*args, **kwargs):
  schema = onnx.defs.get_schema("ArgMin",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ArgMin")(*args, **kwargs)


def ArrayFeatureExtractor(*args, **kwargs):
  schema = onnx.defs.get_schema("ArrayFeatureExtractor",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ArrayFeatureExtractor")(*args, **kwargs)


def Asin(*args, **kwargs):
  schema = onnx.defs.get_schema("Asin",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Asin")(*args, **kwargs)


def Asinh(*args, **kwargs):
  schema = onnx.defs.get_schema("Asinh",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Asinh")(*args, **kwargs)


def Atan(*args, **kwargs):
  schema = onnx.defs.get_schema("Atan",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Atan")(*args, **kwargs)


def Atanh(*args, **kwargs):
  schema = onnx.defs.get_schema("Atanh",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Atanh")(*args, **kwargs)


def AveragePool(*args, **kwargs):
  schema = onnx.defs.get_schema("AveragePool",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.AveragePool")(*args, **kwargs)


def BatchNormalization(*args, **kwargs):
  schema = onnx.defs.get_schema("BatchNormalization",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.BatchNormalization")(*args, **kwargs)


def Binarizer(*args, **kwargs):
  schema = onnx.defs.get_schema("Binarizer",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Binarizer")(*args, **kwargs)


def BitShift(*args, **kwargs):
  schema = onnx.defs.get_schema("BitShift",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.BitShift")(*args, **kwargs)


def Cast(*args, **kwargs):
  schema = onnx.defs.get_schema("Cast",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Cast")(*args, **kwargs)


def CastMap(*args, **kwargs):
  schema = onnx.defs.get_schema("CastMap",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.CastMap")(*args, **kwargs)


def CategoryMapper(*args, **kwargs):
  schema = onnx.defs.get_schema("CategoryMapper",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.CategoryMapper")(*args, **kwargs)


def Ceil(*args, **kwargs):
  schema = onnx.defs.get_schema("Ceil",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Ceil")(*args, **kwargs)


def Celu(*args, **kwargs):
  schema = onnx.defs.get_schema("Celu",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Celu")(*args, **kwargs)


def Clip(*args, **kwargs):
  schema = onnx.defs.get_schema("Clip",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Clip")(*args, **kwargs)


def Compress(*args, **kwargs):
  schema = onnx.defs.get_schema("Compress",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Compress")(*args, **kwargs)


def Concat(*args, **kwargs):
  schema = onnx.defs.get_schema("Concat",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Concat")(*args, **kwargs)


def ConcatFromSequence(*args, **kwargs):
  schema = onnx.defs.get_schema("ConcatFromSequence",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ConcatFromSequence")(*args, **kwargs)


def Constant(*args, **kwargs):
  schema = onnx.defs.get_schema("Constant",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Constant")(*args, **kwargs)


def ConstantOfShape(*args, **kwargs):
  schema = onnx.defs.get_schema("ConstantOfShape",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ConstantOfShape")(*args, **kwargs)


def Conv(*args, **kwargs):
  schema = onnx.defs.get_schema("Conv",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Conv")(*args, **kwargs)


def ConvInteger(*args, **kwargs):
  schema = onnx.defs.get_schema("ConvInteger",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ConvInteger")(*args, **kwargs)


def ConvTranspose(*args, **kwargs):
  schema = onnx.defs.get_schema("ConvTranspose",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ConvTranspose")(*args, **kwargs)


def Cos(*args, **kwargs):
  schema = onnx.defs.get_schema("Cos",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Cos")(*args, **kwargs)


def Cosh(*args, **kwargs):
  schema = onnx.defs.get_schema("Cosh",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Cosh")(*args, **kwargs)


def CumSum(*args, **kwargs):
  schema = onnx.defs.get_schema("CumSum",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.CumSum")(*args, **kwargs)


def DepthToSpace(*args, **kwargs):
  schema = onnx.defs.get_schema("DepthToSpace",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.DepthToSpace")(*args, **kwargs)


def DequantizeLinear(*args, **kwargs):
  schema = onnx.defs.get_schema("DequantizeLinear",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.DequantizeLinear")(*args, **kwargs)


def Det(*args, **kwargs):
  schema = onnx.defs.get_schema("Det",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Det")(*args, **kwargs)


def DictVectorizer(*args, **kwargs):
  schema = onnx.defs.get_schema("DictVectorizer",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.DictVectorizer")(*args, **kwargs)


def Div(*args, **kwargs):
  schema = onnx.defs.get_schema("Div",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Div")(*args, **kwargs)


def Dropout(*args, **kwargs):
  schema = onnx.defs.get_schema("Dropout",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Dropout")(*args, **kwargs)


def DynamicQuantizeLinear(*args, **kwargs):
  schema = onnx.defs.get_schema("DynamicQuantizeLinear",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.DynamicQuantizeLinear")(*args, **kwargs)


def Einsum(*args, **kwargs):
  schema = onnx.defs.get_schema("Einsum",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Einsum")(*args, **kwargs)


def Elu(*args, **kwargs):
  schema = onnx.defs.get_schema("Elu",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Elu")(*args, **kwargs)


def Equal(*args, **kwargs):
  schema = onnx.defs.get_schema("Equal",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Equal")(*args, **kwargs)


def Erf(*args, **kwargs):
  schema = onnx.defs.get_schema("Erf",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Erf")(*args, **kwargs)


def Exp(*args, **kwargs):
  schema = onnx.defs.get_schema("Exp",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Exp")(*args, **kwargs)


def Expand(*args, **kwargs):
  schema = onnx.defs.get_schema("Expand",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Expand")(*args, **kwargs)


def EyeLike(*args, **kwargs):
  schema = onnx.defs.get_schema("EyeLike",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.EyeLike")(*args, **kwargs)


def FeatureVectorizer(*args, **kwargs):
  schema = onnx.defs.get_schema("FeatureVectorizer",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.FeatureVectorizer")(*args, **kwargs)


def Flatten(*args, **kwargs):
  schema = onnx.defs.get_schema("Flatten",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Flatten")(*args, **kwargs)


def Floor(*args, **kwargs):
  schema = onnx.defs.get_schema("Floor",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Floor")(*args, **kwargs)


def GRU(*args, **kwargs):
  schema = onnx.defs.get_schema("GRU",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.GRU")(*args, **kwargs)


def Gather(*args, **kwargs):
  schema = onnx.defs.get_schema("Gather",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Gather")(*args, **kwargs)


def GatherElements(*args, **kwargs):
  schema = onnx.defs.get_schema("GatherElements",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.GatherElements")(*args, **kwargs)


def GatherND(*args, **kwargs):
  schema = onnx.defs.get_schema("GatherND",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.GatherND")(*args, **kwargs)


def Gemm(*args, **kwargs):
  schema = onnx.defs.get_schema("Gemm",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Gemm")(*args, **kwargs)


def GlobalAveragePool(*args, **kwargs):
  schema = onnx.defs.get_schema("GlobalAveragePool",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.GlobalAveragePool")(*args, **kwargs)


def GlobalLpPool(*args, **kwargs):
  schema = onnx.defs.get_schema("GlobalLpPool",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.GlobalLpPool")(*args, **kwargs)


def GlobalMaxPool(*args, **kwargs):
  schema = onnx.defs.get_schema("GlobalMaxPool",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.GlobalMaxPool")(*args, **kwargs)


def Gradient(*args, **kwargs):
  schema = onnx.defs.get_schema("Gradient",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Gradient")(*args, **kwargs)


def Greater(*args, **kwargs):
  schema = onnx.defs.get_schema("Greater",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Greater")(*args, **kwargs)


def GreaterOrEqual(*args, **kwargs):
  schema = onnx.defs.get_schema("GreaterOrEqual",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.GreaterOrEqual")(*args, **kwargs)


def HardSigmoid(*args, **kwargs):
  schema = onnx.defs.get_schema("HardSigmoid",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.HardSigmoid")(*args, **kwargs)


def HardSwish(*args, **kwargs):
  schema = onnx.defs.get_schema("HardSwish",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.HardSwish")(*args, **kwargs)


def Hardmax(*args, **kwargs):
  schema = onnx.defs.get_schema("Hardmax",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Hardmax")(*args, **kwargs)


def Identity(*args, **kwargs):
  schema = onnx.defs.get_schema("Identity",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Identity")(*args, **kwargs)


def If(*args, **kwargs):
  schema = onnx.defs.get_schema("If",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.If")(*args, **kwargs)


def Imputer(*args, **kwargs):
  schema = onnx.defs.get_schema("Imputer",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Imputer")(*args, **kwargs)


def InstanceNormalization(*args, **kwargs):
  schema = onnx.defs.get_schema("InstanceNormalization",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.InstanceNormalization")(*args, **kwargs)


def IsInf(*args, **kwargs):
  schema = onnx.defs.get_schema("IsInf",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.IsInf")(*args, **kwargs)


def IsNaN(*args, **kwargs):
  schema = onnx.defs.get_schema("IsNaN",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.IsNaN")(*args, **kwargs)


def LRN(*args, **kwargs):
  schema = onnx.defs.get_schema("LRN",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.LRN")(*args, **kwargs)


def LSTM(*args, **kwargs):
  schema = onnx.defs.get_schema("LSTM",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.LSTM")(*args, **kwargs)


def LabelEncoder(*args, **kwargs):
  schema = onnx.defs.get_schema("LabelEncoder",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.LabelEncoder")(*args, **kwargs)


def LeakyRelu(*args, **kwargs):
  schema = onnx.defs.get_schema("LeakyRelu",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.LeakyRelu")(*args, **kwargs)


def Less(*args, **kwargs):
  schema = onnx.defs.get_schema("Less",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Less")(*args, **kwargs)


def LessOrEqual(*args, **kwargs):
  schema = onnx.defs.get_schema("LessOrEqual",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.LessOrEqual")(*args, **kwargs)


def LinearClassifier(*args, **kwargs):
  schema = onnx.defs.get_schema("LinearClassifier",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.LinearClassifier")(*args, **kwargs)


def LinearRegressor(*args, **kwargs):
  schema = onnx.defs.get_schema("LinearRegressor",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.LinearRegressor")(*args, **kwargs)


def Log(*args, **kwargs):
  schema = onnx.defs.get_schema("Log",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Log")(*args, **kwargs)


def LogSoftmax(*args, **kwargs):
  schema = onnx.defs.get_schema("LogSoftmax",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.LogSoftmax")(*args, **kwargs)


def Loop(*args, **kwargs):
  schema = onnx.defs.get_schema("Loop",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Loop")(*args, **kwargs)


def LpNormalization(*args, **kwargs):
  schema = onnx.defs.get_schema("LpNormalization",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.LpNormalization")(*args, **kwargs)


def LpPool(*args, **kwargs):
  schema = onnx.defs.get_schema("LpPool",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.LpPool")(*args, **kwargs)


def MatMul(*args, **kwargs):
  schema = onnx.defs.get_schema("MatMul",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.MatMul")(*args, **kwargs)


def MatMulInteger(*args, **kwargs):
  schema = onnx.defs.get_schema("MatMulInteger",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.MatMulInteger")(*args, **kwargs)


def Max(*args, **kwargs):
  schema = onnx.defs.get_schema("Max",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Max")(*args, **kwargs)


def MaxPool(*args, **kwargs):
  schema = onnx.defs.get_schema("MaxPool",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.MaxPool")(*args, **kwargs)


def MaxRoiPool(*args, **kwargs):
  schema = onnx.defs.get_schema("MaxRoiPool",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.MaxRoiPool")(*args, **kwargs)


def MaxUnpool(*args, **kwargs):
  schema = onnx.defs.get_schema("MaxUnpool",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.MaxUnpool")(*args, **kwargs)


def Mean(*args, **kwargs):
  schema = onnx.defs.get_schema("Mean",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Mean")(*args, **kwargs)


def MeanVarianceNormalization(*args, **kwargs):
  schema = onnx.defs.get_schema("MeanVarianceNormalization",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.MeanVarianceNormalization")(*args, **kwargs)


def Min(*args, **kwargs):
  schema = onnx.defs.get_schema("Min",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Min")(*args, **kwargs)


def Mod(*args, **kwargs):
  schema = onnx.defs.get_schema("Mod",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Mod")(*args, **kwargs)


def Momentum(*args, **kwargs):
  schema = onnx.defs.get_schema("Momentum",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Momentum")(*args, **kwargs)


def Mul(*args, **kwargs):
  schema = onnx.defs.get_schema("Mul",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Mul")(*args, **kwargs)


def Multinomial(*args, **kwargs):
  schema = onnx.defs.get_schema("Multinomial",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Multinomial")(*args, **kwargs)


def Neg(*args, **kwargs):
  schema = onnx.defs.get_schema("Neg",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Neg")(*args, **kwargs)


def NegativeLogLikelihoodLoss(*args, **kwargs):
  schema = onnx.defs.get_schema("NegativeLogLikelihoodLoss",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.NegativeLogLikelihoodLoss")(*args, **kwargs)


def NonMaxSuppression(*args, **kwargs):
  schema = onnx.defs.get_schema("NonMaxSuppression",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.NonMaxSuppression")(*args, **kwargs)


def NonZero(*args, **kwargs):
  schema = onnx.defs.get_schema("NonZero",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.NonZero")(*args, **kwargs)


def Normalizer(*args, **kwargs):
  schema = onnx.defs.get_schema("Normalizer",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Normalizer")(*args, **kwargs)


def Not(*args, **kwargs):
  schema = onnx.defs.get_schema("Not",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Not")(*args, **kwargs)


def OneHot(*args, **kwargs):
  schema = onnx.defs.get_schema("OneHot",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.OneHot")(*args, **kwargs)


def OneHotEncoder(*args, **kwargs):
  schema = onnx.defs.get_schema("OneHotEncoder",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.OneHotEncoder")(*args, **kwargs)


def Or(*args, **kwargs):
  schema = onnx.defs.get_schema("Or",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Or")(*args, **kwargs)


def PRelu(*args, **kwargs):
  schema = onnx.defs.get_schema("PRelu",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.PRelu")(*args, **kwargs)


def Pad(*args, **kwargs):
  schema = onnx.defs.get_schema("Pad",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Pad")(*args, **kwargs)


def Pow(*args, **kwargs):
  schema = onnx.defs.get_schema("Pow",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Pow")(*args, **kwargs)


def QLinearConv(*args, **kwargs):
  schema = onnx.defs.get_schema("QLinearConv",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.QLinearConv")(*args, **kwargs)


def QLinearMatMul(*args, **kwargs):
  schema = onnx.defs.get_schema("QLinearMatMul",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.QLinearMatMul")(*args, **kwargs)


def QuantizeLinear(*args, **kwargs):
  schema = onnx.defs.get_schema("QuantizeLinear",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.QuantizeLinear")(*args, **kwargs)


def RNN(*args, **kwargs):
  schema = onnx.defs.get_schema("RNN",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.RNN")(*args, **kwargs)


def RandomNormal(*args, **kwargs):
  schema = onnx.defs.get_schema("RandomNormal",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.RandomNormal")(*args, **kwargs)


def RandomNormalLike(*args, **kwargs):
  schema = onnx.defs.get_schema("RandomNormalLike",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.RandomNormalLike")(*args, **kwargs)


def RandomUniform(*args, **kwargs):
  schema = onnx.defs.get_schema("RandomUniform",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.RandomUniform")(*args, **kwargs)


def RandomUniformLike(*args, **kwargs):
  schema = onnx.defs.get_schema("RandomUniformLike",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.RandomUniformLike")(*args, **kwargs)


def Range(*args, **kwargs):
  schema = onnx.defs.get_schema("Range",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Range")(*args, **kwargs)


def Reciprocal(*args, **kwargs):
  schema = onnx.defs.get_schema("Reciprocal",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Reciprocal")(*args, **kwargs)


def ReduceL1(*args, **kwargs):
  schema = onnx.defs.get_schema("ReduceL1",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ReduceL1")(*args, **kwargs)


def ReduceL2(*args, **kwargs):
  schema = onnx.defs.get_schema("ReduceL2",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ReduceL2")(*args, **kwargs)


def ReduceLogSum(*args, **kwargs):
  schema = onnx.defs.get_schema("ReduceLogSum",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ReduceLogSum")(*args, **kwargs)


def ReduceLogSumExp(*args, **kwargs):
  schema = onnx.defs.get_schema("ReduceLogSumExp",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ReduceLogSumExp")(*args, **kwargs)


def ReduceMax(*args, **kwargs):
  schema = onnx.defs.get_schema("ReduceMax",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ReduceMax")(*args, **kwargs)


def ReduceMean(*args, **kwargs):
  schema = onnx.defs.get_schema("ReduceMean",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ReduceMean")(*args, **kwargs)


def ReduceMin(*args, **kwargs):
  schema = onnx.defs.get_schema("ReduceMin",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ReduceMin")(*args, **kwargs)


def ReduceProd(*args, **kwargs):
  schema = onnx.defs.get_schema("ReduceProd",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ReduceProd")(*args, **kwargs)


def ReduceSum(*args, **kwargs):
  schema = onnx.defs.get_schema("ReduceSum",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ReduceSum")(*args, **kwargs)


def ReduceSumSquare(*args, **kwargs):
  schema = onnx.defs.get_schema("ReduceSumSquare",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ReduceSumSquare")(*args, **kwargs)


def Relu(*args, **kwargs):
  schema = onnx.defs.get_schema("Relu",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Relu")(*args, **kwargs)


def Reshape(*args, **kwargs):
  schema = onnx.defs.get_schema("Reshape",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Reshape")(*args, **kwargs)


def Resize(*args, **kwargs):
  schema = onnx.defs.get_schema("Resize",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Resize")(*args, **kwargs)


def ReverseSequence(*args, **kwargs):
  schema = onnx.defs.get_schema("ReverseSequence",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ReverseSequence")(*args, **kwargs)


def RoiAlign(*args, **kwargs):
  schema = onnx.defs.get_schema("RoiAlign",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.RoiAlign")(*args, **kwargs)


def Round(*args, **kwargs):
  schema = onnx.defs.get_schema("Round",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Round")(*args, **kwargs)


def SVMClassifier(*args, **kwargs):
  schema = onnx.defs.get_schema("SVMClassifier",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.SVMClassifier")(*args, **kwargs)


def SVMRegressor(*args, **kwargs):
  schema = onnx.defs.get_schema("SVMRegressor",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.SVMRegressor")(*args, **kwargs)


def Scaler(*args, **kwargs):
  schema = onnx.defs.get_schema("Scaler",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Scaler")(*args, **kwargs)


def Scan(*args, **kwargs):
  schema = onnx.defs.get_schema("Scan",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Scan")(*args, **kwargs)


def Scatter(*args, **kwargs):
  schema = onnx.defs.get_schema("Scatter",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Scatter")(*args, **kwargs)


def ScatterElements(*args, **kwargs):
  schema = onnx.defs.get_schema("ScatterElements",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ScatterElements")(*args, **kwargs)


def ScatterND(*args, **kwargs):
  schema = onnx.defs.get_schema("ScatterND",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ScatterND")(*args, **kwargs)


def Selu(*args, **kwargs):
  schema = onnx.defs.get_schema("Selu",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Selu")(*args, **kwargs)


def SequenceAt(*args, **kwargs):
  schema = onnx.defs.get_schema("SequenceAt",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.SequenceAt")(*args, **kwargs)


def SequenceConstruct(*args, **kwargs):
  schema = onnx.defs.get_schema("SequenceConstruct",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.SequenceConstruct")(*args, **kwargs)


def SequenceEmpty(*args, **kwargs):
  schema = onnx.defs.get_schema("SequenceEmpty",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.SequenceEmpty")(*args, **kwargs)


def SequenceErase(*args, **kwargs):
  schema = onnx.defs.get_schema("SequenceErase",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.SequenceErase")(*args, **kwargs)


def SequenceInsert(*args, **kwargs):
  schema = onnx.defs.get_schema("SequenceInsert",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.SequenceInsert")(*args, **kwargs)


def SequenceLength(*args, **kwargs):
  schema = onnx.defs.get_schema("SequenceLength",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.SequenceLength")(*args, **kwargs)


def Shape(*args, **kwargs):
  schema = onnx.defs.get_schema("Shape",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Shape")(*args, **kwargs)


def Shrink(*args, **kwargs):
  schema = onnx.defs.get_schema("Shrink",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Shrink")(*args, **kwargs)


def Sigmoid(*args, **kwargs):
  schema = onnx.defs.get_schema("Sigmoid",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Sigmoid")(*args, **kwargs)


def Sign(*args, **kwargs):
  schema = onnx.defs.get_schema("Sign",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Sign")(*args, **kwargs)


def Sin(*args, **kwargs):
  schema = onnx.defs.get_schema("Sin",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Sin")(*args, **kwargs)


def Sinh(*args, **kwargs):
  schema = onnx.defs.get_schema("Sinh",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Sinh")(*args, **kwargs)


def Size(*args, **kwargs):
  schema = onnx.defs.get_schema("Size",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Size")(*args, **kwargs)


def Slice(*args, **kwargs):
  schema = onnx.defs.get_schema("Slice",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Slice")(*args, **kwargs)


def Softmax(*args, **kwargs):
  schema = onnx.defs.get_schema("Softmax",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Softmax")(*args, **kwargs)


def SoftmaxCrossEntropyLoss(*args, **kwargs):
  schema = onnx.defs.get_schema("SoftmaxCrossEntropyLoss",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.SoftmaxCrossEntropyLoss")(*args, **kwargs)


def Softplus(*args, **kwargs):
  schema = onnx.defs.get_schema("Softplus",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Softplus")(*args, **kwargs)


def Softsign(*args, **kwargs):
  schema = onnx.defs.get_schema("Softsign",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Softsign")(*args, **kwargs)


def SpaceToDepth(*args, **kwargs):
  schema = onnx.defs.get_schema("SpaceToDepth",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.SpaceToDepth")(*args, **kwargs)


def Split(*args, **kwargs):
  schema = onnx.defs.get_schema("Split",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Split")(*args, **kwargs)


def SplitToSequence(*args, **kwargs):
  schema = onnx.defs.get_schema("SplitToSequence",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.SplitToSequence")(*args, **kwargs)


def Sqrt(*args, **kwargs):
  schema = onnx.defs.get_schema("Sqrt",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Sqrt")(*args, **kwargs)


def Squeeze(*args, **kwargs):
  schema = onnx.defs.get_schema("Squeeze",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Squeeze")(*args, **kwargs)


def StringNormalizer(*args, **kwargs):
  schema = onnx.defs.get_schema("StringNormalizer",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.StringNormalizer")(*args, **kwargs)


def Sub(*args, **kwargs):
  schema = onnx.defs.get_schema("Sub",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Sub")(*args, **kwargs)


def Sum(*args, **kwargs):
  schema = onnx.defs.get_schema("Sum",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Sum")(*args, **kwargs)


def Tan(*args, **kwargs):
  schema = onnx.defs.get_schema("Tan",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Tan")(*args, **kwargs)


def Tanh(*args, **kwargs):
  schema = onnx.defs.get_schema("Tanh",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Tanh")(*args, **kwargs)


def TfIdfVectorizer(*args, **kwargs):
  schema = onnx.defs.get_schema("TfIdfVectorizer",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.TfIdfVectorizer")(*args, **kwargs)


def ThresholdedRelu(*args, **kwargs):
  schema = onnx.defs.get_schema("ThresholdedRelu",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ThresholdedRelu")(*args, **kwargs)


def Tile(*args, **kwargs):
  schema = onnx.defs.get_schema("Tile",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Tile")(*args, **kwargs)


def TopK(*args, **kwargs):
  schema = onnx.defs.get_schema("TopK",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.TopK")(*args, **kwargs)


def Transpose(*args, **kwargs):
  schema = onnx.defs.get_schema("Transpose",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Transpose")(*args, **kwargs)


def TreeEnsembleClassifier(*args, **kwargs):
  schema = onnx.defs.get_schema("TreeEnsembleClassifier",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.TreeEnsembleClassifier")(*args, **kwargs)


def TreeEnsembleRegressor(*args, **kwargs):
  schema = onnx.defs.get_schema("TreeEnsembleRegressor",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.TreeEnsembleRegressor")(*args, **kwargs)


def Trilu(*args, **kwargs):
  schema = onnx.defs.get_schema("Trilu",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Trilu")(*args, **kwargs)


def Unique(*args, **kwargs):
  schema = onnx.defs.get_schema("Unique",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Unique")(*args, **kwargs)


def Unsqueeze(*args, **kwargs):
  schema = onnx.defs.get_schema("Unsqueeze",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Unsqueeze")(*args, **kwargs)


def Upsample(*args, **kwargs):
  schema = onnx.defs.get_schema("Upsample",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Upsample")(*args, **kwargs)


def Where(*args, **kwargs):
  schema = onnx.defs.get_schema("Where",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Where")(*args, **kwargs)


def Xor(*args, **kwargs):
  schema = onnx.defs.get_schema("Xor",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.Xor")(*args, **kwargs)


def ZipMap(*args, **kwargs):
  schema = onnx.defs.get_schema("ZipMap",
                                max_inclusive_version=OPSET_VER,
                                domain="")
  return getattr(sys.modules[f"{mod_name}.ops"], 
                 f"v{schema.since_version}.ZipMap")(*args, **kwargs)


__all__ = ["Input", "Output", "Abs", "Acos", "Acosh", "Adagrad", "Adam", "Add", "And", "ArgMax", "ArgMin", "ArrayFeatureExtractor", "Asin", "Asinh", "Atan", "Atanh", "AveragePool", "BatchNormalization", "Binarizer", "BitShift", "Cast", "CastMap", "CategoryMapper", "Ceil", "Celu", "Clip", "Compress", "Concat", "ConcatFromSequence", "Constant", "ConstantOfShape", "Conv", "ConvInteger", "ConvTranspose", "Cos", "Cosh", "CumSum", "DepthToSpace", "DequantizeLinear", "Det", "DictVectorizer", "Div", "Dropout", "DynamicQuantizeLinear", "Einsum", "Elu", "Equal", "Erf", "Exp", "Expand", "EyeLike", "FeatureVectorizer", "Flatten", "Floor", "GRU", "Gather", "GatherElements", "GatherND", "Gemm", "GlobalAveragePool", "GlobalLpPool", "GlobalMaxPool", "Gradient", "Greater", "GreaterOrEqual", "HardSigmoid", "HardSwish", "Hardmax", "Identity", "If", "Imputer", "InstanceNormalization", "IsInf", "IsNaN", "LRN", "LSTM", "LabelEncoder", "LeakyRelu", "Less", "LessOrEqual", "LinearClassifier", "LinearRegressor", "Log", "LogSoftmax", "Loop", "LpNormalization", "LpPool", "MatMul", "MatMulInteger", "Max", "MaxPool", "MaxRoiPool", "MaxUnpool", "Mean", "MeanVarianceNormalization", "Min", "Mod", "Momentum", "Mul", "Multinomial", "Neg", "NegativeLogLikelihoodLoss", "NonMaxSuppression", "NonZero", "Normalizer", "Not", "OneHot", "OneHotEncoder", "Or", "PRelu", "Pad", "Pow", "QLinearConv", "QLinearMatMul", "QuantizeLinear", "RNN", "RandomNormal", "RandomNormalLike", "RandomUniform", "RandomUniformLike", "Range", "Reciprocal", "ReduceL1", "ReduceL2", "ReduceLogSum", "ReduceLogSumExp", "ReduceMax", "ReduceMean", "ReduceMin", "ReduceProd", "ReduceSum", "ReduceSumSquare", "Relu", "Reshape", "Resize", "ReverseSequence", "RoiAlign", "Round", "SVMClassifier", "SVMRegressor", "Scaler", "Scan", "Scatter", "ScatterElements", "ScatterND", "Selu", "SequenceAt", "SequenceConstruct", "SequenceEmpty", "SequenceErase", "SequenceInsert", "SequenceLength", "Shape", "Shrink", "Sigmoid", "Sign", "Sin", "Sinh", "Size", "Slice", "Softmax", "SoftmaxCrossEntropyLoss", "Softplus", "Softsign", "SpaceToDepth", "Split", "SplitToSequence", "Sqrt", "Squeeze", "StringNormalizer", "Sub", "Sum", "Tan", "Tanh", "TfIdfVectorizer", "ThresholdedRelu", "Tile", "TopK", "Transpose", "TreeEnsembleClassifier", "TreeEnsembleRegressor", "Trilu", "Unique", "Unsqueeze", "Upsample", "Where", "Xor", "ZipMap"]


# Autogenerated by onnx-model-maker. Don't modify it manually.

import onnx
import onnx.helper
import onnx.numpy_helper
from onnx_model_maker import omm
from onnx_model_maker import onnx_mm_export
from onnx_model_maker.ops.op_helper import _add_input


@onnx_mm_export("v13.GatherND")
def GatherND(data, indices, **kwargs):
  _inputs = []
  for i in (data, indices):
    _add_input(i, _inputs)

  idx = omm.op_counter["GatherND"]
  omm.op_counter["GatherND"] += 1
  node = onnx.helper.make_node("GatherND",
                               _inputs, [f"_t_GatherND_{idx}"],
                               name=f"GatherND_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.ScatterND")
def ScatterND(data, indices, updates, **kwargs):
  _inputs = []
  for i in (data, indices, updates):
    _add_input(i, _inputs)

  idx = omm.op_counter["ScatterND"]
  omm.op_counter["ScatterND"] += 1
  node = onnx.helper.make_node("ScatterND",
                               _inputs, [f"_t_ScatterND_{idx}"],
                               name=f"ScatterND_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.ScatterElements")
def ScatterElements(data, indices, updates, **kwargs):
  _inputs = []
  for i in (data, indices, updates):
    _add_input(i, _inputs)

  idx = omm.op_counter["ScatterElements"]
  omm.op_counter["ScatterElements"] += 1
  node = onnx.helper.make_node("ScatterElements",
                               _inputs, [f"_t_ScatterElements_{idx}"],
                               name=f"ScatterElements_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.GatherElements")
def GatherElements(data, indices, **kwargs):
  _inputs = []
  for i in (data, indices):
    _add_input(i, _inputs)

  idx = omm.op_counter["GatherElements"]
  omm.op_counter["GatherElements"] += 1
  node = onnx.helper.make_node("GatherElements",
                               _inputs, [f"_t_GatherElements_{idx}"],
                               name=f"GatherElements_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.QuantizeLinear")
def QuantizeLinear(x, y_scale, y_zero_point=None, **kwargs):
  _inputs = []
  for i in (x, y_scale, y_zero_point):
    _add_input(i, _inputs)

  idx = omm.op_counter["QuantizeLinear"]
  omm.op_counter["QuantizeLinear"] += 1
  node = onnx.helper.make_node("QuantizeLinear",
                               _inputs, [f"_t_QuantizeLinear_{idx}"],
                               name=f"QuantizeLinear_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.MeanVarianceNormalization")
def MeanVarianceNormalization(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["MeanVarianceNormalization"]
  omm.op_counter["MeanVarianceNormalization"] += 1
  node = onnx.helper.make_node("MeanVarianceNormalization",
                               _inputs, [f"_t_MeanVarianceNormalization_{idx}"],
                               name=f"MeanVarianceNormalization_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.NonZero")
def NonZero(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["NonZero"]
  omm.op_counter["NonZero"] += 1
  node = onnx.helper.make_node("NonZero",
                               _inputs, [f"_t_NonZero_{idx}"],
                               name=f"NonZero_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Sign")
def Sign(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Sign"]
  omm.op_counter["Sign"] += 1
  node = onnx.helper.make_node("Sign",
                               _inputs, [f"_t_Sign_{idx}"],
                               name=f"Sign_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.IsNaN")
def IsNaN(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["IsNaN"]
  omm.op_counter["IsNaN"] += 1
  node = onnx.helper.make_node("IsNaN",
                               _inputs, [f"_t_IsNaN_{idx}"],
                               name=f"IsNaN_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Mod")
def Mod(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["Mod"]
  omm.op_counter["Mod"] += 1
  node = onnx.helper.make_node("Mod",
                               _inputs, [f"_t_Mod_{idx}"],
                               name=f"Mod_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.DequantizeLinear")
def DequantizeLinear(x, x_scale, x_zero_point=None, **kwargs):
  _inputs = []
  for i in (x, x_scale, x_zero_point):
    _add_input(i, _inputs)

  idx = omm.op_counter["DequantizeLinear"]
  omm.op_counter["DequantizeLinear"] += 1
  node = onnx.helper.make_node("DequantizeLinear",
                               _inputs, [f"_t_DequantizeLinear_{idx}"],
                               name=f"DequantizeLinear_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Expand")
def Expand(input, shape, **kwargs):
  _inputs = []
  for i in (input, shape):
    _add_input(i, _inputs)

  idx = omm.op_counter["Expand"]
  omm.op_counter["Expand"] += 1
  node = onnx.helper.make_node("Expand",
                               _inputs, [f"_t_Expand_{idx}"],
                               name=f"Expand_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Floor")
def Floor(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Floor"]
  omm.op_counter["Floor"] += 1
  node = onnx.helper.make_node("Floor",
                               _inputs, [f"_t_Floor_{idx}"],
                               name=f"Floor_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.ReduceSumSquare")
def ReduceSumSquare(data, **kwargs):
  _inputs = []
  for i in (data, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["ReduceSumSquare"]
  omm.op_counter["ReduceSumSquare"] += 1
  node = onnx.helper.make_node("ReduceSumSquare",
                               _inputs, [f"_t_ReduceSumSquare_{idx}"],
                               name=f"ReduceSumSquare_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Tile")
def Tile(input, repeats, **kwargs):
  _inputs = []
  for i in (input, repeats):
    _add_input(i, _inputs)

  idx = omm.op_counter["Tile"]
  omm.op_counter["Tile"] += 1
  node = onnx.helper.make_node("Tile",
                               _inputs, [f"_t_Tile_{idx}"],
                               name=f"Tile_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Sub")
def Sub(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["Sub"]
  omm.op_counter["Sub"] += 1
  node = onnx.helper.make_node("Sub",
                               _inputs, [f"_t_Sub_{idx}"],
                               name=f"Sub_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Squeeze")
def Squeeze(data, axes=None, **kwargs):
  _inputs = []
  for i in (data, axes):
    _add_input(i, _inputs)

  idx = omm.op_counter["Squeeze"]
  omm.op_counter["Squeeze"] += 1
  node = onnx.helper.make_node("Squeeze",
                               _inputs, [f"_t_Squeeze_{idx}"],
                               name=f"Squeeze_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.ReduceLogSum")
def ReduceLogSum(data, **kwargs):
  _inputs = []
  for i in (data, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["ReduceLogSum"]
  omm.op_counter["ReduceLogSum"] += 1
  node = onnx.helper.make_node("ReduceLogSum",
                               _inputs, [f"_t_ReduceLogSum_{idx}"],
                               name=f"ReduceLogSum_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Split")
def Split(input, split=None, **kwargs):
  _inputs = []
  for i in (input, split):
    _add_input(i, _inputs)

  idx = omm.op_counter["Split"]
  omm.op_counter["Split"] += 1
  node = onnx.helper.make_node("Split",
                               _inputs, [f"_t_Split_{idx}_{i}" for i in range(len(split))],
                               name=f"Split_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Sqrt")
def Sqrt(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Sqrt"]
  omm.op_counter["Sqrt"] += 1
  node = onnx.helper.make_node("Sqrt",
                               _inputs, [f"_t_Sqrt_{idx}"],
                               name=f"Sqrt_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.SpaceToDepth")
def SpaceToDepth(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["SpaceToDepth"]
  omm.op_counter["SpaceToDepth"] += 1
  node = onnx.helper.make_node("SpaceToDepth",
                               _inputs, [f"_t_SpaceToDepth_{idx}"],
                               name=f"SpaceToDepth_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Softmax")
def Softmax(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Softmax"]
  omm.op_counter["Softmax"] += 1
  node = onnx.helper.make_node("Softmax",
                               _inputs, [f"_t_Softmax_{idx}"],
                               name=f"Softmax_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Erf")
def Erf(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Erf"]
  omm.op_counter["Erf"] += 1
  node = onnx.helper.make_node("Erf",
                               _inputs, [f"_t_Erf_{idx}"],
                               name=f"Erf_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Size")
def Size(data, **kwargs):
  _inputs = []
  for i in (data, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Size"]
  omm.op_counter["Size"] += 1
  node = onnx.helper.make_node("Size",
                               _inputs, [f"_t_Size_{idx}"],
                               name=f"Size_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Max")
def Max(data_0, **kwargs):
  _inputs = []
  for i in (data_0, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Max"]
  omm.op_counter["Max"] += 1
  node = onnx.helper.make_node("Max",
                               _inputs, [f"_t_Max_{idx}"],
                               name=f"Max_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Tanh")
def Tanh(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Tanh"]
  omm.op_counter["Tanh"] += 1
  node = onnx.helper.make_node("Tanh",
                               _inputs, [f"_t_Tanh_{idx}"],
                               name=f"Tanh_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Transpose")
def Transpose(data, **kwargs):
  _inputs = []
  for i in (data, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Transpose"]
  omm.op_counter["Transpose"] += 1
  node = onnx.helper.make_node("Transpose",
                               _inputs, [f"_t_Transpose_{idx}"],
                               name=f"Transpose_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Shape")
def Shape(data, **kwargs):
  _inputs = []
  for i in (data, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Shape"]
  omm.op_counter["Shape"] += 1
  node = onnx.helper.make_node("Shape",
                               _inputs, [f"_t_Shape_{idx}"],
                               name=f"Shape_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Sum")
def Sum(data_0, **kwargs):
  _inputs = []
  for i in (data_0, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Sum"]
  omm.op_counter["Sum"] += 1
  node = onnx.helper.make_node("Sum",
                               _inputs, [f"_t_Sum_{idx}"],
                               name=f"Sum_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Relu")
def Relu(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Relu"]
  omm.op_counter["Relu"] += 1
  node = onnx.helper.make_node("Relu",
                               _inputs, [f"_t_Relu_{idx}"],
                               name=f"Relu_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.NegativeLogLikelihoodLoss")
def NegativeLogLikelihoodLoss(input, target, weight=None, **kwargs):
  _inputs = []
  for i in (input, target, weight):
    _add_input(i, _inputs)

  idx = omm.op_counter["NegativeLogLikelihoodLoss"]
  omm.op_counter["NegativeLogLikelihoodLoss"] += 1
  node = onnx.helper.make_node("NegativeLogLikelihoodLoss",
                               _inputs, [f"_t_NegativeLogLikelihoodLoss_{idx}"],
                               name=f"NegativeLogLikelihoodLoss_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.ReduceMin")
def ReduceMin(data, **kwargs):
  _inputs = []
  for i in (data, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["ReduceMin"]
  omm.op_counter["ReduceMin"] += 1
  node = onnx.helper.make_node("ReduceMin",
                               _inputs, [f"_t_ReduceMin_{idx}"],
                               name=f"ReduceMin_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.ReduceL1")
def ReduceL1(data, **kwargs):
  _inputs = []
  for i in (data, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["ReduceL1"]
  omm.op_counter["ReduceL1"] += 1
  node = onnx.helper.make_node("ReduceL1",
                               _inputs, [f"_t_ReduceL1_{idx}"],
                               name=f"ReduceL1_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Reciprocal")
def Reciprocal(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Reciprocal"]
  omm.op_counter["Reciprocal"] += 1
  node = onnx.helper.make_node("Reciprocal",
                               _inputs, [f"_t_Reciprocal_{idx}"],
                               name=f"Reciprocal_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Mul")
def Mul(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["Mul"]
  omm.op_counter["Mul"] += 1
  node = onnx.helper.make_node("Mul",
                               _inputs, [f"_t_Mul_{idx}"],
                               name=f"Mul_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Sigmoid")
def Sigmoid(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Sigmoid"]
  omm.op_counter["Sigmoid"] += 1
  node = onnx.helper.make_node("Sigmoid",
                               _inputs, [f"_t_Sigmoid_{idx}"],
                               name=f"Sigmoid_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Pad")
def Pad(data, pads, constant_value=None, **kwargs):
  _inputs = []
  for i in (data, pads, constant_value):
    _add_input(i, _inputs)

  idx = omm.op_counter["Pad"]
  omm.op_counter["Pad"] += 1
  node = onnx.helper.make_node("Pad",
                               _inputs, [f"_t_Pad_{idx}"],
                               name=f"Pad_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Slice")
def Slice(data, starts, ends, axes=None, steps=None, **kwargs):
  _inputs = []
  for i in (data, starts, ends, axes, steps):
    _add_input(i, _inputs)

  idx = omm.op_counter["Slice"]
  omm.op_counter["Slice"] += 1
  node = onnx.helper.make_node("Slice",
                               _inputs, [f"_t_Slice_{idx}"],
                               name=f"Slice_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Greater")
def Greater(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["Greater"]
  omm.op_counter["Greater"] += 1
  node = onnx.helper.make_node("Greater",
                               _inputs, [f"_t_Greater_{idx}"],
                               name=f"Greater_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.ReduceLogSumExp")
def ReduceLogSumExp(data, **kwargs):
  _inputs = []
  for i in (data, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["ReduceLogSumExp"]
  omm.op_counter["ReduceLogSumExp"] += 1
  node = onnx.helper.make_node("ReduceLogSumExp",
                               _inputs, [f"_t_ReduceLogSumExp_{idx}"],
                               name=f"ReduceLogSumExp_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Neg")
def Neg(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Neg"]
  omm.op_counter["Neg"] += 1
  node = onnx.helper.make_node("Neg",
                               _inputs, [f"_t_Neg_{idx}"],
                               name=f"Neg_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Mean")
def Mean(data_0, **kwargs):
  _inputs = []
  for i in (data_0, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Mean"]
  omm.op_counter["Mean"] += 1
  node = onnx.helper.make_node("Mean",
                               _inputs, [f"_t_Mean_{idx}"],
                               name=f"Mean_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Reshape")
def Reshape(data, shape, **kwargs):
  _inputs = []
  for i in (data, shape):
    _add_input(i, _inputs)

  idx = omm.op_counter["Reshape"]
  omm.op_counter["Reshape"] += 1
  node = onnx.helper.make_node("Reshape",
                               _inputs, [f"_t_Reshape_{idx}"],
                               name=f"Reshape_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.ReduceL2")
def ReduceL2(data, **kwargs):
  _inputs = []
  for i in (data, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["ReduceL2"]
  omm.op_counter["ReduceL2"] += 1
  node = onnx.helper.make_node("ReduceL2",
                               _inputs, [f"_t_ReduceL2_{idx}"],
                               name=f"ReduceL2_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Flatten")
def Flatten(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Flatten"]
  omm.op_counter["Flatten"] += 1
  node = onnx.helper.make_node("Flatten",
                               _inputs, [f"_t_Flatten_{idx}"],
                               name=f"Flatten_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.ReduceMax")
def ReduceMax(data, **kwargs):
  _inputs = []
  for i in (data, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["ReduceMax"]
  omm.op_counter["ReduceMax"] += 1
  node = onnx.helper.make_node("ReduceMax",
                               _inputs, [f"_t_ReduceMax_{idx}"],
                               name=f"ReduceMax_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Loop")
def Loop(M, cond, v_initial=None, **kwargs):
  _inputs = []
  for i in (M, cond, v_initial):
    _add_input(i, _inputs)

  idx = omm.op_counter["Loop"]
  omm.op_counter["Loop"] += 1
  node = onnx.helper.make_node("Loop",
                               _inputs, [f"_t_Loop_{idx}"],
                               name=f"Loop_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Log")
def Log(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Log"]
  omm.op_counter["Log"] += 1
  node = onnx.helper.make_node("Log",
                               _inputs, [f"_t_Log_{idx}"],
                               name=f"Log_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Cast")
def Cast(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Cast"]
  omm.op_counter["Cast"] += 1
  node = onnx.helper.make_node("Cast",
                               _inputs, [f"_t_Cast_{idx}"],
                               name=f"Cast_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Unsqueeze")
def Unsqueeze(data, axes, **kwargs):
  _inputs = []
  for i in (data, axes):
    _add_input(i, _inputs)

  idx = omm.op_counter["Unsqueeze"]
  omm.op_counter["Unsqueeze"] += 1
  node = onnx.helper.make_node("Unsqueeze",
                               _inputs, [f"_t_Unsqueeze_{idx}"],
                               name=f"Unsqueeze_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.ArgMax")
def ArgMax(data, **kwargs):
  _inputs = []
  for i in (data, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["ArgMax"]
  omm.op_counter["ArgMax"] += 1
  node = onnx.helper.make_node("ArgMax",
                               _inputs, [f"_t_ArgMax_{idx}"],
                               name=f"ArgMax_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.LRN")
def LRN(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["LRN"]
  omm.op_counter["LRN"] += 1
  node = onnx.helper.make_node("LRN",
                               _inputs, [f"_t_LRN_{idx}"],
                               name=f"LRN_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.SoftmaxCrossEntropyLoss")
def SoftmaxCrossEntropyLoss(scores, labels, weights=None, **kwargs):
  _inputs = []
  for i in (scores, labels, weights):
    _add_input(i, _inputs)

  idx = omm.op_counter["SoftmaxCrossEntropyLoss"]
  omm.op_counter["SoftmaxCrossEntropyLoss"] += 1
  node = onnx.helper.make_node("SoftmaxCrossEntropyLoss",
                               _inputs, [f"_t_SoftmaxCrossEntropyLoss_{idx}"],
                               name=f"SoftmaxCrossEntropyLoss_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Concat")
def Concat(inputs, **kwargs):
  _inputs = []
  for i in (inputs, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Concat"]
  omm.op_counter["Concat"] += 1
  node = onnx.helper.make_node("Concat",
                               _inputs, [f"_t_Concat_{idx}"],
                               name=f"Concat_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.If")
def If(cond, **kwargs):
  _inputs = []
  for i in (cond, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["If"]
  omm.op_counter["If"] += 1
  node = onnx.helper.make_node("If",
                               _inputs, [f"_t_If_{idx}"],
                               name=f"If_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Clip")
def Clip(input, min=None, max=None, **kwargs):
  _inputs = []
  for i in (input, min, max):
    _add_input(i, _inputs)

  idx = omm.op_counter["Clip"]
  omm.op_counter["Clip"] += 1
  node = onnx.helper.make_node("Clip",
                               _inputs, [f"_t_Clip_{idx}"],
                               name=f"Clip_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Identity")
def Identity(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Identity"]
  omm.op_counter["Identity"] += 1
  node = onnx.helper.make_node("Identity",
                               _inputs, [f"_t_Identity_{idx}"],
                               name=f"Identity_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.ReduceProd")
def ReduceProd(data, **kwargs):
  _inputs = []
  for i in (data, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["ReduceProd"]
  omm.op_counter["ReduceProd"] += 1
  node = onnx.helper.make_node("ReduceProd",
                               _inputs, [f"_t_ReduceProd_{idx}"],
                               name=f"ReduceProd_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Gather")
def Gather(data, indices, **kwargs):
  _inputs = []
  for i in (data, indices):
    _add_input(i, _inputs)

  idx = omm.op_counter["Gather"]
  omm.op_counter["Gather"] += 1
  node = onnx.helper.make_node("Gather",
                               _inputs, [f"_t_Gather_{idx}"],
                               name=f"Gather_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.MatMul")
def MatMul(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["MatMul"]
  omm.op_counter["MatMul"] += 1
  node = onnx.helper.make_node("MatMul",
                               _inputs, [f"_t_MatMul_{idx}"],
                               name=f"MatMul_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Resize")
def Resize(X, roi=None, scales=None, sizes=None, **kwargs):
  _inputs = []
  for i in (X, roi, scales, sizes):
    _add_input(i, _inputs)

  idx = omm.op_counter["Resize"]
  omm.op_counter["Resize"] += 1
  node = onnx.helper.make_node("Resize",
                               _inputs, [f"_t_Resize_{idx}"],
                               name=f"Resize_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Exp")
def Exp(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Exp"]
  omm.op_counter["Exp"] += 1
  node = onnx.helper.make_node("Exp",
                               _inputs, [f"_t_Exp_{idx}"],
                               name=f"Exp_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.ArgMin")
def ArgMin(data, **kwargs):
  _inputs = []
  for i in (data, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["ArgMin"]
  omm.op_counter["ArgMin"] += 1
  node = onnx.helper.make_node("ArgMin",
                               _inputs, [f"_t_ArgMin_{idx}"],
                               name=f"ArgMin_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Add")
def Add(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["Add"]
  omm.op_counter["Add"] += 1
  node = onnx.helper.make_node("Add",
                               _inputs, [f"_t_Add_{idx}"],
                               name=f"Add_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Constant")
def Constant(**kwargs):
  _inputs = []
  for i in ():
    _add_input(i, _inputs)

  idx = omm.op_counter["Constant"]
  omm.op_counter["Constant"] += 1
  node = onnx.helper.make_node("Constant",
                               _inputs, [f"_t_Constant_{idx}"],
                               name=f"Constant_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Equal")
def Equal(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["Equal"]
  omm.op_counter["Equal"] += 1
  node = onnx.helper.make_node("Equal",
                               _inputs, [f"_t_Equal_{idx}"],
                               name=f"Equal_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.ReduceSum")
def ReduceSum(data, axes=None, **kwargs):
  _inputs = []
  for i in (data, axes):
    _add_input(i, _inputs)

  idx = omm.op_counter["ReduceSum"]
  omm.op_counter["ReduceSum"] += 1
  node = onnx.helper.make_node("ReduceSum",
                               _inputs, [f"_t_ReduceSum_{idx}"],
                               name=f"ReduceSum_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Pow")
def Pow(X, Y, **kwargs):
  _inputs = []
  for i in (X, Y):
    _add_input(i, _inputs)

  idx = omm.op_counter["Pow"]
  omm.op_counter["Pow"] += 1
  node = onnx.helper.make_node("Pow",
                               _inputs, [f"_t_Pow_{idx}"],
                               name=f"Pow_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Min")
def Min(data_0, **kwargs):
  _inputs = []
  for i in (data_0, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Min"]
  omm.op_counter["Min"] += 1
  node = onnx.helper.make_node("Min",
                               _inputs, [f"_t_Min_{idx}"],
                               name=f"Min_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Div")
def Div(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["Div"]
  omm.op_counter["Div"] += 1
  node = onnx.helper.make_node("Div",
                               _inputs, [f"_t_Div_{idx}"],
                               name=f"Div_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.ReduceMean")
def ReduceMean(data, **kwargs):
  _inputs = []
  for i in (data, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["ReduceMean"]
  omm.op_counter["ReduceMean"] += 1
  node = onnx.helper.make_node("ReduceMean",
                               _inputs, [f"_t_ReduceMean_{idx}"],
                               name=f"ReduceMean_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Less")
def Less(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["Less"]
  omm.op_counter["Less"] += 1
  node = onnx.helper.make_node("Less",
                               _inputs, [f"_t_Less_{idx}"],
                               name=f"Less_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Dropout")
def Dropout(data, ratio=None, training_mode=None, **kwargs):
  _inputs = []
  for i in (data, ratio, training_mode):
    _add_input(i, _inputs)

  idx = omm.op_counter["Dropout"]
  omm.op_counter["Dropout"] += 1
  node = onnx.helper.make_node("Dropout",
                               _inputs, [f"_t_Dropout_{idx}"],
                               name=f"Dropout_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.DepthToSpace")
def DepthToSpace(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["DepthToSpace"]
  omm.op_counter["DepthToSpace"] += 1
  node = onnx.helper.make_node("DepthToSpace",
                               _inputs, [f"_t_DepthToSpace_{idx}"],
                               name=f"DepthToSpace_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Ceil")
def Ceil(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Ceil"]
  omm.op_counter["Ceil"] += 1
  node = onnx.helper.make_node("Ceil",
                               _inputs, [f"_t_Ceil_{idx}"],
                               name=f"Ceil_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.LogSoftmax")
def LogSoftmax(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["LogSoftmax"]
  omm.op_counter["LogSoftmax"] += 1
  node = onnx.helper.make_node("LogSoftmax",
                               _inputs, [f"_t_LogSoftmax_{idx}"],
                               name=f"LogSoftmax_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Hardmax")
def Hardmax(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Hardmax"]
  omm.op_counter["Hardmax"] += 1
  node = onnx.helper.make_node("Hardmax",
                               _inputs, [f"_t_Hardmax_{idx}"],
                               name=f"Hardmax_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Abs")
def Abs(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Abs"]
  omm.op_counter["Abs"] += 1
  node = onnx.helper.make_node("Abs",
                               _inputs, [f"_t_Abs_{idx}"],
                               name=f"Abs_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v13.Gemm")
def Gemm(A, B, C=None, **kwargs):
  _inputs = []
  for i in (A, B, C):
    _add_input(i, _inputs)

  idx = omm.op_counter["Gemm"]
  omm.op_counter["Gemm"] += 1
  node = onnx.helper.make_node("Gemm",
                               _inputs, [f"_t_Gemm_{idx}"],
                               name=f"Gemm_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node



import collections
import sys

import onnx
from onnx import IR_VERSION
import onnx.onnx_cpp2py_export.checker as C
from onnx.helper import make_model, make_opsetid

__all__ = ["omm", "mod_name", "reset_model", "set_model", "onnx_mm_export"]

# OPSET_VER = onnx.defs.onnx_opset_version()
OPSET_VER = 13


class OnnxModelMaker:

  def __init__(self, opset_ver=OPSET_VER):
    self.opset_import = make_opsetid("", opset_ver)
    self.model = make_model(onnx.GraphProto(),
                            opset_imports=[self.opset_import])
    self.op_counter = collections.Counter()
    self.ctx = C.CheckerContext()
    self.ctx.ir_version = IR_VERSION
    self.ctx.opset_imports = {'': opset_ver}

  def reset_model(self):
    self.model = make_model(onnx.GraphProto(),
                            opset_imports=[self.opset_import])
    self.op_counter = collections.Counter()

  def set_model(self, model):
    self.model = model


omm = OnnxModelMaker()
mod_name = __name__
reset_model = omm.reset_model
set_model = omm.set_model
ctx = omm.ctx


class onnx_mm_export(object):

  def __init__(self, *args, **kwargs):
    self._names = args

  def __call__(self, func):
    for a in self._names:
      mod = sys.modules[f"{mod_name}.ops"]
      setattr(mod, a, func)
    pass

    return func



# Autogenerated by onnx-model-maker. Don't modify it manually.

import onnx
import onnx.helper
import onnx.numpy_helper
from onnx_model_maker import omm
from onnx_model_maker import onnx_mm_export
from onnx_model_maker.ops.op_helper import _add_input


@onnx_mm_export("v3.GRU")
def GRU(X, W, R, B=None, sequence_lens=None, initial_h=None, **kwargs):
  _inputs = []
  for i in (X, W, R, B, sequence_lens, initial_h):
    _add_input(i, _inputs)

  idx = omm.op_counter["GRU"]
  omm.op_counter["GRU"] += 1
  node = onnx.helper.make_node("GRU",
                               _inputs, [f"_t_GRU_{idx}"],
                               name=f"GRU_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node



# Autogenerated by onnx-model-maker. Don't modify it manually.

import onnx
import onnx.helper
import onnx.numpy_helper
from onnx_model_maker import omm
from onnx_model_maker import onnx_mm_export
from onnx_model_maker.ops.op_helper import _add_input


@onnx_mm_export("v9.MeanVarianceNormalization")
def MeanVarianceNormalization(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["MeanVarianceNormalization"]
  omm.op_counter["MeanVarianceNormalization"] += 1
  node = onnx.helper.make_node("MeanVarianceNormalization",
                               _inputs, [f"_t_MeanVarianceNormalization_{idx}"],
                               name=f"MeanVarianceNormalization_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.TfIdfVectorizer")
def TfIdfVectorizer(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["TfIdfVectorizer"]
  omm.op_counter["TfIdfVectorizer"] += 1
  node = onnx.helper.make_node("TfIdfVectorizer",
                               _inputs, [f"_t_TfIdfVectorizer_{idx}"],
                               name=f"TfIdfVectorizer_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.NonZero")
def NonZero(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["NonZero"]
  omm.op_counter["NonZero"] += 1
  node = onnx.helper.make_node("NonZero",
                               _inputs, [f"_t_NonZero_{idx}"],
                               name=f"NonZero_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Sign")
def Sign(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Sign"]
  omm.op_counter["Sign"] += 1
  node = onnx.helper.make_node("Sign",
                               _inputs, [f"_t_Sign_{idx}"],
                               name=f"Sign_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.IsNaN")
def IsNaN(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["IsNaN"]
  omm.op_counter["IsNaN"] += 1
  node = onnx.helper.make_node("IsNaN",
                               _inputs, [f"_t_IsNaN_{idx}"],
                               name=f"IsNaN_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Shrink")
def Shrink(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Shrink"]
  omm.op_counter["Shrink"] += 1
  node = onnx.helper.make_node("Shrink",
                               _inputs, [f"_t_Shrink_{idx}"],
                               name=f"Shrink_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Sinh")
def Sinh(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Sinh"]
  omm.op_counter["Sinh"] += 1
  node = onnx.helper.make_node("Sinh",
                               _inputs, [f"_t_Sinh_{idx}"],
                               name=f"Sinh_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Scatter")
def Scatter(data, indices, updates, **kwargs):
  _inputs = []
  for i in (data, indices, updates):
    _add_input(i, _inputs)

  idx = omm.op_counter["Scatter"]
  omm.op_counter["Scatter"] += 1
  node = onnx.helper.make_node("Scatter",
                               _inputs, [f"_t_Scatter_{idx}"],
                               name=f"Scatter_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.OneHot")
def OneHot(indices, depth, values, **kwargs):
  _inputs = []
  for i in (indices, depth, values):
    _add_input(i, _inputs)

  idx = omm.op_counter["OneHot"]
  omm.op_counter["OneHot"] += 1
  node = onnx.helper.make_node("OneHot",
                               _inputs, [f"_t_OneHot_{idx}"],
                               name=f"OneHot_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.MaxUnpool")
def MaxUnpool(X, I, output_shape=None, **kwargs):
  _inputs = []
  for i in (X, I, output_shape):
    _add_input(i, _inputs)

  idx = omm.op_counter["MaxUnpool"]
  omm.op_counter["MaxUnpool"] += 1
  node = onnx.helper.make_node("MaxUnpool",
                               _inputs, [f"_t_MaxUnpool_{idx}"],
                               name=f"MaxUnpool_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.EyeLike")
def EyeLike(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["EyeLike"]
  omm.op_counter["EyeLike"] += 1
  node = onnx.helper.make_node("EyeLike",
                               _inputs, [f"_t_EyeLike_{idx}"],
                               name=f"EyeLike_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.ConstantOfShape")
def ConstantOfShape(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["ConstantOfShape"]
  omm.op_counter["ConstantOfShape"] += 1
  node = onnx.helper.make_node("ConstantOfShape",
                               _inputs, [f"_t_ConstantOfShape_{idx}"],
                               name=f"ConstantOfShape_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Compress")
def Compress(input, condition, **kwargs):
  _inputs = []
  for i in (input, condition):
    _add_input(i, _inputs)

  idx = omm.op_counter["Compress"]
  omm.op_counter["Compress"] += 1
  node = onnx.helper.make_node("Compress",
                               _inputs, [f"_t_Compress_{idx}"],
                               name=f"Compress_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Scan")
def Scan(initial_state_and_scan_inputs, **kwargs):
  _inputs = []
  for i in (initial_state_and_scan_inputs, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Scan"]
  omm.op_counter["Scan"] += 1
  node = onnx.helper.make_node("Scan",
                               _inputs, [f"_t_Scan_{idx}"],
                               name=f"Scan_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Upsample")
def Upsample(X, scales, **kwargs):
  _inputs = []
  for i in (X, scales):
    _add_input(i, _inputs)

  idx = omm.op_counter["Upsample"]
  omm.op_counter["Upsample"] += 1
  node = onnx.helper.make_node("Upsample",
                               _inputs, [f"_t_Upsample_{idx}"],
                               name=f"Upsample_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Acosh")
def Acosh(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Acosh"]
  omm.op_counter["Acosh"] += 1
  node = onnx.helper.make_node("Acosh",
                               _inputs, [f"_t_Acosh_{idx}"],
                               name=f"Acosh_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Where")
def Where(condition, X, Y, **kwargs):
  _inputs = []
  for i in (condition, X, Y):
    _add_input(i, _inputs)

  idx = omm.op_counter["Where"]
  omm.op_counter["Where"] += 1
  node = onnx.helper.make_node("Where",
                               _inputs, [f"_t_Where_{idx}"],
                               name=f"Where_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Erf")
def Erf(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Erf"]
  omm.op_counter["Erf"] += 1
  node = onnx.helper.make_node("Erf",
                               _inputs, [f"_t_Erf_{idx}"],
                               name=f"Erf_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Asinh")
def Asinh(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Asinh"]
  omm.op_counter["Asinh"] += 1
  node = onnx.helper.make_node("Asinh",
                               _inputs, [f"_t_Asinh_{idx}"],
                               name=f"Asinh_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Greater")
def Greater(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["Greater"]
  omm.op_counter["Greater"] += 1
  node = onnx.helper.make_node("Greater",
                               _inputs, [f"_t_Greater_{idx}"],
                               name=f"Greater_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Flatten")
def Flatten(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Flatten"]
  omm.op_counter["Flatten"] += 1
  node = onnx.helper.make_node("Flatten",
                               _inputs, [f"_t_Flatten_{idx}"],
                               name=f"Flatten_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.BatchNormalization")
def BatchNormalization(X, scale, B, mean, var, **kwargs):
  _inputs = []
  for i in (X, scale, B, mean, var):
    _add_input(i, _inputs)

  idx = omm.op_counter["BatchNormalization"]
  omm.op_counter["BatchNormalization"] += 1
  node = onnx.helper.make_node("BatchNormalization",
                               _inputs, [f"_t_BatchNormalization_{idx}"],
                               name=f"BatchNormalization_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Cosh")
def Cosh(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Cosh"]
  omm.op_counter["Cosh"] += 1
  node = onnx.helper.make_node("Cosh",
                               _inputs, [f"_t_Cosh_{idx}"],
                               name=f"Cosh_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Cast")
def Cast(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Cast"]
  omm.op_counter["Cast"] += 1
  node = onnx.helper.make_node("Cast",
                               _inputs, [f"_t_Cast_{idx}"],
                               name=f"Cast_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.PRelu")
def PRelu(X, slope, **kwargs):
  _inputs = []
  for i in (X, slope):
    _add_input(i, _inputs)

  idx = omm.op_counter["PRelu"]
  omm.op_counter["PRelu"] += 1
  node = onnx.helper.make_node("PRelu",
                               _inputs, [f"_t_PRelu_{idx}"],
                               name=f"PRelu_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Atanh")
def Atanh(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Atanh"]
  omm.op_counter["Atanh"] += 1
  node = onnx.helper.make_node("Atanh",
                               _inputs, [f"_t_Atanh_{idx}"],
                               name=f"Atanh_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.MatMul")
def MatMul(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["MatMul"]
  omm.op_counter["MatMul"] += 1
  node = onnx.helper.make_node("MatMul",
                               _inputs, [f"_t_MatMul_{idx}"],
                               name=f"MatMul_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Constant")
def Constant(**kwargs):
  _inputs = []
  for i in ():
    _add_input(i, _inputs)

  idx = omm.op_counter["Constant"]
  omm.op_counter["Constant"] += 1
  node = onnx.helper.make_node("Constant",
                               _inputs, [f"_t_Constant_{idx}"],
                               name=f"Constant_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Less")
def Less(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["Less"]
  omm.op_counter["Less"] += 1
  node = onnx.helper.make_node("Less",
                               _inputs, [f"_t_Less_{idx}"],
                               name=f"Less_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v9.Gemm")
def Gemm(A, B, C, **kwargs):
  _inputs = []
  for i in (A, B, C):
    _add_input(i, _inputs)

  idx = omm.op_counter["Gemm"]
  omm.op_counter["Gemm"] += 1
  node = onnx.helper.make_node("Gemm",
                               _inputs, [f"_t_Gemm_{idx}"],
                               name=f"Gemm_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node



# Autogenerated by onnx-model-maker. Don't modify it manually.

import onnx
import onnx.helper
import onnx.numpy_helper
from onnx_model_maker import omm
from onnx_model_maker import onnx_mm_export
from onnx_model_maker.ops.op_helper import _add_input


@onnx_mm_export("v14.HardSwish")
def HardSwish(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["HardSwish"]
  omm.op_counter["HardSwish"] += 1
  node = onnx.helper.make_node("HardSwish",
                               _inputs, [f"_t_HardSwish_{idx}"],
                               name=f"HardSwish_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v14.CumSum")
def CumSum(x, axis, **kwargs):
  _inputs = []
  for i in (x, axis):
    _add_input(i, _inputs)

  idx = omm.op_counter["CumSum"]
  omm.op_counter["CumSum"] += 1
  node = onnx.helper.make_node("CumSum",
                               _inputs, [f"_t_CumSum_{idx}"],
                               name=f"CumSum_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v14.Trilu")
def Trilu(input, k=None, **kwargs):
  _inputs = []
  for i in (input, k):
    _add_input(i, _inputs)

  idx = omm.op_counter["Trilu"]
  omm.op_counter["Trilu"] += 1
  node = onnx.helper.make_node("Trilu",
                               _inputs, [f"_t_Trilu_{idx}"],
                               name=f"Trilu_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v14.Sub")
def Sub(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["Sub"]
  omm.op_counter["Sub"] += 1
  node = onnx.helper.make_node("Sub",
                               _inputs, [f"_t_Sub_{idx}"],
                               name=f"Sub_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v14.Relu")
def Relu(X, **kwargs):
  _inputs = []
  for i in (X, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Relu"]
  omm.op_counter["Relu"] += 1
  node = onnx.helper.make_node("Relu",
                               _inputs, [f"_t_Relu_{idx}"],
                               name=f"Relu_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v14.Mul")
def Mul(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["Mul"]
  omm.op_counter["Mul"] += 1
  node = onnx.helper.make_node("Mul",
                               _inputs, [f"_t_Mul_{idx}"],
                               name=f"Mul_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v14.RNN")
def RNN(X, W, R, B=None, sequence_lens=None, initial_h=None, **kwargs):
  _inputs = []
  for i in (X, W, R, B, sequence_lens, initial_h):
    _add_input(i, _inputs)

  idx = omm.op_counter["RNN"]
  omm.op_counter["RNN"] += 1
  node = onnx.helper.make_node("RNN",
                               _inputs, [f"_t_RNN_{idx}"],
                               name=f"RNN_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v14.Reshape")
def Reshape(data, shape, **kwargs):
  _inputs = []
  for i in (data, shape):
    _add_input(i, _inputs)

  idx = omm.op_counter["Reshape"]
  omm.op_counter["Reshape"] += 1
  node = onnx.helper.make_node("Reshape",
                               _inputs, [f"_t_Reshape_{idx}"],
                               name=f"Reshape_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v14.BatchNormalization")
def BatchNormalization(X, scale, B, input_mean, input_var, **kwargs):
  _inputs = []
  for i in (X, scale, B, input_mean, input_var):
    _add_input(i, _inputs)

  idx = omm.op_counter["BatchNormalization"]
  omm.op_counter["BatchNormalization"] += 1
  node = onnx.helper.make_node("BatchNormalization",
                               _inputs, [f"_t_BatchNormalization_{idx}"],
                               name=f"BatchNormalization_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v14.LSTM")
def LSTM(X, W, R, B=None, sequence_lens=None, initial_h=None, initial_c=None, P=None, **kwargs):
  _inputs = []
  for i in (X, W, R, B, sequence_lens, initial_h, initial_c, P):
    _add_input(i, _inputs)

  idx = omm.op_counter["LSTM"]
  omm.op_counter["LSTM"] += 1
  node = onnx.helper.make_node("LSTM",
                               _inputs, [f"_t_LSTM_{idx}"],
                               name=f"LSTM_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v14.Identity")
def Identity(input, **kwargs):
  _inputs = []
  for i in (input, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Identity"]
  omm.op_counter["Identity"] += 1
  node = onnx.helper.make_node("Identity",
                               _inputs, [f"_t_Identity_{idx}"],
                               name=f"Identity_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v14.GRU")
def GRU(X, W, R, B=None, sequence_lens=None, initial_h=None, **kwargs):
  _inputs = []
  for i in (X, W, R, B, sequence_lens, initial_h):
    _add_input(i, _inputs)

  idx = omm.op_counter["GRU"]
  omm.op_counter["GRU"] += 1
  node = onnx.helper.make_node("GRU",
                               _inputs, [f"_t_GRU_{idx}"],
                               name=f"GRU_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v14.Add")
def Add(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["Add"]
  omm.op_counter["Add"] += 1
  node = onnx.helper.make_node("Add",
                               _inputs, [f"_t_Add_{idx}"],
                               name=f"Add_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node


@onnx_mm_export("v14.Div")
def Div(A, B, **kwargs):
  _inputs = []
  for i in (A, B):
    _add_input(i, _inputs)

  idx = omm.op_counter["Div"]
  omm.op_counter["Div"] += 1
  node = onnx.helper.make_node("Div",
                               _inputs, [f"_t_Div_{idx}"],
                               name=f"Div_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node



# Autogenerated by onnx-model-maker. Don't modify it manually.

import onnx
import onnx.helper
import onnx.numpy_helper
from onnx_model_maker import omm
from onnx_model_maker import onnx_mm_export
from onnx_model_maker.ops.op_helper import _add_input


@onnx_mm_export("v4.Concat")
def Concat(inputs, **kwargs):
  _inputs = []
  for i in (inputs, ):
    _add_input(i, _inputs)

  idx = omm.op_counter["Concat"]
  omm.op_counter["Concat"] += 1
  node = onnx.helper.make_node("Concat",
                               _inputs, [f"_t_Concat_{idx}"],
                               name=f"Concat_{idx}",
                               **kwargs)
  onnx.checker.check_node(node, omm.ctx)
  omm.model.graph.node.append(node)
  return node



import onnx
import torch

from onnx_pytorch.op_code_generators import OpCodeGenerator


class AddOpCodeGenerator(OpCodeGenerator):

  def __init__(self,
               onnx_ver=onnx.defs.onnx_opset_version(),
               torch_ver=torch.__version__):
    super(AddOpCodeGenerator, self).__init__(onnx_ver, torch_ver)

  def gen(self, node, value_infos, initializers):
    inputs_str, outputs_str = self.gen_input_output_string(node, initializers)
    init_str, forward_str = [], []
    forward_str.append(f"{outputs_str[0]} = {' + '.join(inputs_str)}")
    return {"init": init_str, "forward": forward_str}



import logging

import onnx
import onnx.numpy_helper
from onnx.numpy_helper import to_array
import torch

import glob
import os

modules = glob.glob(os.path.join(os.path.dirname(__file__), "*.py"))
__all__ = [
    os.path.basename(f)[:-3]
    for f in modules
    if os.path.isfile(f) and not f.endswith('__init__.py')
] + ["get_op_code_generator"]


class OpCodeGenerator:

  def __init__(self,
               onnx_ver=onnx.defs.onnx_opset_version(),
               torch_ver=torch.__version__):
    self.onnx_ver = onnx_ver
    self.torch_ver = torch_ver
    self.onnx_op = self.__class__.__name__.replace("OpCodeGenerator", "")
    self.schema = onnx.defs.get_schema(self.onnx_op,
                                       max_inclusive_version=onnx_ver)
    if self.schema is not None:
      self.attr_default = {}
      for a, i in self.schema.attributes.items():
        try:
          default_value = onnx.helper.get_attribute_value(i.default_value)
          self.attr_default[a] = default_value
        except Exception as e:
          logging.warning(
              f"Cannot get default value for {a} of {self.onnx_op}.")

  def gen(self, node, value_infos, initializers):
    raise Exception

  def get_attr_value_dict(self, node):
    attr_value_dict = {}
    for a in node.attribute:
      attr_value_dict[a.name] = onnx.helper.get_attribute_value(a)
    attr_value_dict = dict(
        list(self.attr_default.items()) + list(attr_value_dict.items()))
    return attr_value_dict

  def gen_input_output_string(self,
                              node,
                              initializers,
                              input_num=None,
                              output_num=None):
    inputs_str, outputs_str = [], []
    input_num, output_num = input_num or len(node.input), output_num or len(
        node.output)
    for n, f, ls in ((input_num, node.input, inputs_str),
                     (output_num, node.output, outputs_str)):
      for i in range(n):
        ls.append("self.{}".format(f[i]) if f[i] not in
                  initializers else "self.__variables[\"{}\"]".format(f[i]))
    return inputs_str, outputs_str

  def gen_params_str(self, **kwargs):
    params = []
    for k, v in kwargs.items():
      v_str = v if type(v) == str else v.__repr__()
      params.append(f"'{k}': {v_str}")
    return ', '.join(params).__repr__()[1:-1]


class ReduceOpCodeGenerator(OpCodeGenerator):

  def __init__(self,
               onnx_ver=onnx.defs.onnx_opset_version(),
               torch_ver=torch.__version__):
    super(ReduceOpCodeGenerator, self).__init__(onnx_ver, torch_ver)

  def _get_dim(self, attr_value_dict, d, node, initializers):
    if "axes" in attr_value_dict:
      dim = attr_value_dict["axes"]
    else:
      dim = list(range(d))
      if len(node.input) > 1:
        dim = initializers.get(node.input[1], None)
        assert dim is not None, "Currently ReduceOpCodeGenerator only support all of [axes] is in initializers."
        dim = list(to_array(dim))
    return dim


__op_gen_dict = {}


def get_op_code_generator(op, **kwargs):
  op_code_gen_name = "{}OpCodeGenerator".format(op)
  if op_code_gen_name in __op_gen_dict:
    return __op_gen_dict[op_code_gen_name]
  mod = globals().get(op, None)
  if mod is None:
    return None
  __op_gen_dict[op_code_gen_name] = getattr(mod, op_code_gen_name)(**kwargs)
  return __op_gen_dict[op_code_gen_name]
